# Node.js, Express, TypeORM, PostgreSQL: CRUD Rest API

In this article, you'll learn how to build CRUD RESTful API with Node.js, ExpressJs, TypeORM, and PostgreSQL. We will define the database schema with TypeORM and run the migration command to push the TypeORM schema to the database. Next, we will create higher-level CRUD function to perform the CRUD operations.

![Node.js, Express, TypeORM, PostgreSQL: CRUD Rest API](https://codevoweb.com/wp-content/uploads/2022/05/Node.js-Express-TypeORM-PostgreSQL-CRUD-Rest-API.webp)

## Topics Covered

- Node.js, TypeORM, PostgreSQL CRUD RESTful API Overview
- Project Structure
- Model Data with TypeORM and PostgreSQL
    - Define a Base Entity
    - Add One-to-Many Relationship to User Entity
    - Complete User Entity
    - Create a Post Entity
- Create Validation Schemas with Zod
- Create Services to Communicate with Database
- Create Route Controllers
    - Create a New Post Controller
    - Get a Single Post Controller
    - Get All Posts Controller
    - Update a Single Post Controller
    - Delete a Single Post Controller
- Create Routes with Express
- Add the Routes to the Express Middleware Pipeline
- Run Database Migration with TypeORM

Read the entire article here: [https://codevoweb.com/node-express-typeorm-postgresql-rest-api](https://codevoweb.com/node-express-typeorm-postgresql-rest-api)

Articles in this series:

### 1. API with Node.js + PostgreSQL + TypeORM: Project Setup

[API with Node.js + PostgreSQL + TypeORM: Project Setup](https://codevoweb.com/api-node-postgresql-typeorm-project-setup)

### 2. API with Node.js + PostgreSQL + TypeORM: JWT Authentication

[API with Node.js + PostgreSQL + TypeORM: JWT Authentication](https://codevoweb.com/api-node-postgresql-typeorm-jwt-authentication)

### 3. API with Node.js + PostgreSQL + TypeORM: Send Emails

[API with Node.js + PostgreSQL + TypeORM: Send Emails](https://codevoweb.com/api-node-postgresql-typeorm-send-emails)

### 4. Node.js, Express, TypeORM, PostgreSQL: CRUD Rest API

[Node.js, Express, TypeORM, PostgreSQL: CRUD Rest API](https://codevoweb.com/node-express-typeorm-postgresql-rest-api)

### 5. Node.js and PostgreSQL: Upload and Resize Multiple Images

[Node.js and PostgreSQL: Upload and Resize Multiple Images](https://codevoweb.com/node-postgresql-upload-resize-multiple-images)
